@@ -1,16 +1,16 @@
 /***************************************************************************
- * Unit:    raster            release 0.31                                 *
+ * Unit:    raster            release 0.33                                 *
  * Purpose: Prototypes for general manipulation n dimensional matrices     *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                                *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                                *
  ***************************************************************************/
 #ifndef __Rasters_h
 #define __Rasters_h
 
 #include "typedfs.h"
 
-#define RASTER_VERSION (0x100*0 | 31)
+#define RASTER_VERSION (0x100*0 | 33)
 
 #ifndef No_Memory
  #define No_Memory    0x1
@@ -174,7 +174,7 @@ public: mutable long UsageCount;
 
 	virtual int GetPlanes(void) const {return(0);};
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
-	virtual char Channels(void) const {return 1;};
+	virtual unsigned char Channels(void) const {return 1;};
 	void *GetRow(void)          {return(Data1D);};
 
 /* This set of functions copy internal data in the proper format to the given buffer. */
@@ -202,6 +202,7 @@ protected:
 	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const {PTR_SetValue1D(RAW_Data1D,x,(uint32_t)NewValue);};
         virtual void PTR_Get(const void *RAW_Data1D, Raster1DAbstract &R1) const;
         virtual void PTR_Set(void *RAW_Data1D, const Raster1DAbstract &R1);
+        //virtual void PTR_Get(const void *RAW_Data1D, unsigned x, RGBQuad *RGB) const {RGB->O=0;RGB->R=RGB->G=RGB->B=PTR_GetValue1D(RAW_Data1D,x);};
 #endif
 };
 Raster1DAbstract *CreateRaster1D(unsigned Size1D, int Planes);
@@ -214,7 +215,7 @@ public:
   virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("Raster1DAbstractRGB::SetValue1DRAW");
 
   virtual unsigned GetSize1D(void) const {return(Size1D);};
-  virtual char Channels(void) const {return 3;};
+  virtual unsigned char Channels(void) const {return 3;};
 
   virtual void Set(const Raster1DAbstract &R1);
   virtual void Set(const Raster1DAbstract &R1, const Raster1DAbstract &Palette);
@@ -249,7 +250,7 @@ public:
   virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("Raster1DAbstractRGBA::SetValue1DRAW");
 
   virtual unsigned GetSize1D(void) const {return(Size1D);};
-  virtual char Channels(void) const {return 4;};
+  virtual unsigned char Channels(void) const {return 4;};
 
   virtual void Set(const Raster1DAbstract &R1);
 
