@@ -1,10 +1,10 @@
 /*************************************************************
- * Unit:    raster            release 0.32                   *
+ * Unit:    raster            release 0.33                   *
  * Purpose: General manipulation n dimensional matrices      *
  *          n = 1, 2 and 3.			             *
  * Modul:   raster.cc                                        *
  * Licency: GPL or LGPL                                      *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                  *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                  *
  *************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -68,10 +68,10 @@ void Raster1DAbstract::Erase1DStub(void)
 void Raster1DAbstract::Allocate1D(unsigned NewSize1D)
 {
  if(Data1D!=NULL) 
-   {
+ {
    if(Size1D==NewSize1D) return;	// No reallocation needed.
    free(Data1D); Data1D=NULL;
-   }
+ }
  if(NewSize1D==0) return;
  const unsigned long SzBit = (unsigned long)labs(GetPlanes()) * NewSize1D;
  Data1D = malloc((SzBit+7)/8);
@@ -2452,6 +2452,18 @@ void Raster1D_8BitRGB::Set(const Raster1DAbstract &R1)
  Raster1DAbstractRGB::Set(R1);
 }
 
+#ifdef OPTIMISE_SPEED
+void  Raster1D_8BitRGB::Set(unsigned x, const RGBQuad *RGB)
+
+{
+  if(Size1D<=x || RGB==NULL) return;
+  x *= 3;
+  ((uint8_t *)Data1D)[x] = RGB->R & 0xFF;
+  ((uint8_t *)Data1D)[x+1] = RGB->G & 0xFF;
+  ((uint8_t *)Data1D)[x+2] = RGB->B & 0xFF;
+}
+#endif
+
 
 #ifdef _REENTRANT
 
@@ -2873,31 +2885,30 @@ return(Raster);
 
 void Raster2DAbstract::Erase2DStub(void)
 {
-unsigned SaveSize1D;
-
+ //printf("Erasing Ras2D |%p|",Data2D);
  if(Shadow)
-   {
-   Data2D=NULL;
-   Size2D=0;
+ {
+   Data2D = NULL;
+   Size2D = 0;
    Erase1DStub();
    return;
-   }
+ }
 
  if(Data2D)
-   {
-   SaveSize1D = Size1D;
+ {
+   const unsigned SaveSize1D = Size1D;
    for(unsigned i=0; i<Size2D; i++)
 	{
-	Size1D=SaveSize1D;
-	Data1D=Data2D[i];
+	Size1D = SaveSize1D;
+	Data1D = Data2D[i];
 	Raster1DAbstract::Erase1D();
 	}
    free(Data2D);
    Data2D = NULL;
-   }
+ }
  else
    Raster1DAbstract::Erase1D();
-Size2D=0;
+ Size2D = 0;
 }
 
 
@@ -2946,6 +2957,7 @@ unsigned i;
      return;
      }
    }
+ //printf("Allocate2D |%p|",Data2D);
 }
 
 
@@ -2983,7 +2995,7 @@ void Raster2DAbstract::Set(unsigned Offset1D, unsigned Offset2D, const RGBQuad *
 {
   if(Data2D==NULL || Offset2D>=Size2D) return;
   Data1D = Data2D[Offset2D];
-  ((Raster1DAbstract*)this)->Set(Offset1D,RGB);		//Raster1DAbstract::Get() forces only one method not using VMT.
+  ((Raster1DAbstract*)this)->Set(Offset1D,RGB);		//Raster1DAbstract::Set() forces only one method not using VMT.
 }
 
 
@@ -3173,6 +3185,7 @@ if(Raster)
 	}
      }
    }
+   //printf("CreateRaster2D |%p|",Raster->Data2D);
 
 return(Raster);
 }
