@@ -1,5 +1,5 @@
 /****************************************************
-* unit:    strings           release 0.25           *
+* unit:    strings           release 0.26           *
 * purpose: general manipulation with text strings   *
 * Licency: GPL or LGPL                              *
 * Copyright: (c) 1998-2021 Jaroslav Fojtik          *
@@ -15,13 +15,21 @@
 #include "stringa.h"
 
 
-#define ALLIGN_ALLOC 2
+/// Allocation tunning.
+/// The optimal value on AMD Win32 seems to be 2
+/// From benchmark ... Addition loop time: 1:1.049294us 2:0.946128us 4:0.954430us
+#ifndef ALLIGN_ALLOC
+ #define ALLIGN_ALLOC 2
+#endif
 
 
 #ifdef ALLIGN_ALLOC
 inline size_t FIX_ALLOC(const size_t size)
 {
-#if ALLIGN_ALLOC==2
+#if ALLIGN_ALLOC<=1
+  return size;
+#else
+ #if ALLIGN_ALLOC==2
   return (size+1) & ~1;
 #else
  #if ALLIGN_ALLOC==4
@@ -30,6 +38,7 @@ inline size_t FIX_ALLOC(const size_t size)
   return (size+7) & ~7;
  #endif
 #endif
+#endif
 }
 #else
  #define FIX_ALLOC(x) (x)
