@@ -20,7 +20,7 @@
 
 Modified by:
    Arturo Tena <arturo@directmail.org>
-   Jaroslav Fojtik <fojtik@penguin.cz>
+   Jaroslav Fojtik <JaFojtik@seznam.cz>
  */
 
 #ifndef __COLE_H
