@@ -15,7 +15,7 @@
 
 
 #if !defined(__DJGPP__)
-#include "../jobs/csext.h"
+#include "../atoms/include/csext.h"
 #endif
 
 #if defined(__DJGPP__) || defined(_WIN32)
@@ -521,7 +521,7 @@ int main(int argc, char *argv[])
 {
 FILE *F;
 codepage internal;
-codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1276, cpkam,
+codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
 	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5, iso_8859_6,
          unicode,koi8cs,koi8r,
@@ -611,9 +611,10 @@ int TimeoutCounter;
  if(!LoadCodePage("cp1253",cp1253,0)) return -7;
  LoadCodePage("cp1254",cp1254,0);
  if(!LoadCodePage("cp1255",cp1255,0)) return -8;
- if(!LoadCodePage("cp1276",cp1276,0)) return -9;
+ if(!LoadCodePage("cp1256",cp1256,0)) return -9;
+ if(!LoadCodePage("cp1276",cp1276,0)) return -10;
 
- if(!LoadCodePage("kam",cpkam,0)) return -10;
+ if(!LoadCodePage("kam",cpkam,0)) return -11;
  LoadCodePage("koi8cs",koi8cs,0);
  LoadCodePage("koi8_r",koi8r,0);
 
@@ -696,6 +697,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
  BuildTranslator(cpkam,internal,F);		cpkam.Erase();
+ fprintf(F,"WCpTranslator cp895internal(\"cp895TOinternal\",255,kam_internal);\n\n");	// alias
 
  BuildTranslator(iso_8859_1,internal,F);	iso_8859_1.Erase();
  BuildTranslator(iso_8859_2,internal,F);	iso_8859_2.Erase();
@@ -711,6 +713,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
  BuildTranslator(cp1253,internal,F);		cp1253.Erase();
  BuildTranslator(cp1254,internal,F);		cp1254.Erase();
  BuildTranslator(cp1255,internal,F);		cp1255.Erase();
+ BuildTranslator(cp1256,internal,F);		cp1256.Erase();
  BuildTranslator(cp1276,internal,F);		// no erase, will be needed
  BuildTranslator(koi8cs,internal,F);		koi8cs.Erase();
  BuildTranslator(koi8r,internal,F);		koi8r.Erase();
