@@ -1140,23 +1140,23 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 		      Remove1stArg(Str1,Header);
 		      if(!Header.isEmpty())
 			{
-			char DefaultAllign = 'c';
+			char DefaultAlign = 'c';
 			for(j=0; j<length(Header); j++)
 			  {
 			  if(Header[j]=='&')
 			    {
-			    strB += DefaultAllign;
-			    DefaultAllign = 'c';
+			    strB += DefaultAlign;
+			    DefaultAlign = 'c';
 			    continue;
 			    }
 			  if(Header[j]=='A')
 			    {
-			    if(!strncmp(Header()+j,"ALIGNC",6)) {DefaultAllign='c';continue;}
-			    if(!strncmp(Header()+j,"ALIGNL",6)) {DefaultAllign='l';continue;}
-		            if(!strncmp(Header()+j,"ALIGNR",6)) {DefaultAllign='r';continue;}
+			    if(!strncmp(Header()+j,"ALIGNC",6)) {DefaultAlign='c';continue;}
+			    if(!strncmp(Header()+j,"ALIGNL",6)) {DefaultAlign='l';continue;}
+		            if(!strncmp(Header()+j,"ALIGNR",6)) {DefaultAlign='r';continue;}
 			    }
 			  }
-			strB += DefaultAllign;
+			strB += DefaultAlign;
 		        break;
                         }
 		      }
