@@ -1,9 +1,9 @@
 /***************************************************************************
- * Unit:    raster            release 0.32                                 *
+ * Unit:    raster            release 0.33                                 *
  * Purpose: Prototypes for general manipulation n dimensional matrices     *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                                *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                                *
  ***************************************************************************/
 #ifndef __IMAGE_H__
 #define __IMAGE_H__
@@ -15,15 +15,17 @@
 #include "stringa.h"
 
 
-#define RAS_IMG_VERSION (0x200 | 75)
+#define RAS_IMG_VERSION (0x200 | 78)
 
-/*Definition of errors while Loading/Saving File(s)*/
+// Definition of errors while Loading/Saving File(s)
 #define ErrOK		  0
 #define ErrOpenFile	 -1
 #define ErrReadFile	 -2
 #define ErrWriteFile	 -3
 #define ErrBadFileFormat -4
-#define ErrMissingRaster -5
+#define ErrEmptyRaster   -5
+#define ErrUnsupportedResolution -6
+#define ErrAccessData	 -7
 
 #define ErrNoMem	-10
 
@@ -119,6 +121,8 @@ typedef Image (* TLoadPicture)(const char *Name);
 typedef int (*TSavePicture)(const char *Name, const Image &Img);
 
 #define FILE_FORMAT_CAP_EXIF	1
+#define FILE_FORMAT_256_COLORS	2
+#define FILE_FORMAT_DUPLICATE	4
 
 class TImageFileHandler
 	{
