@@ -106,31 +106,32 @@ return(sign?-n:n);
 
 /** This function reads double value from a file stream.
  * @param[in]	  F	    File stream used for reading numbers.
- * @param[in,out] pch       Character that is already read from the stream.
+ * @param[in,out] pch       Character that is already read from the stream, NULL is tolerated.
  * @return	Value read. */
 double ReadDouble(FILE *F, char *pch)
 {
   int i;
   char ch, arr[32];
 
-  i = 0;
-
   if(pch!=NULL)
-    {
-    ch = arr[0] = *pch;
-    i++;
-    }
-
-  while(i<(sizeof(arr)-1) && !feof(F))
   {
+    ch = *pch;
+  }
+  else
+  {
+    i = fgetc(F);
+    if(i==EOF) return 0;
+    ch = i;
+  }
+
+  i = 0;
+  while(isdigit(ch) || ch=='.' || ch=='e' || ch=='E' || ch=='+' || ch=='-')
+  {
+    arr[i] = ch;
+    i++;
+
     ch = fgetc(F);
-    if(isdigit(ch) || ch=='.' || ch=='e' || ch=='E' || ch=='+' || ch=='-')
-    {
-      arr[i] = ch;
-      i++;
-      continue;
-    }
-    break;
+    if(feof(F)) break;
   }
 
  if(pch) *pch=ch;
