@@ -6,8 +6,11 @@
 // These support flags could be predefined externally.
 
 #ifdef NO_IMG
+ #define SupportAAI 0
  #define SupportART 0
+ #define SupportAVS 0
  #define SupportBMP 2	//Read procedure only
+ #define SupportCUR 0
  #define SupportCUT 0
  #define SupportCSV 0
  #define SupportDIB 0
@@ -26,15 +29,20 @@
  #define SupportRAS 0
  #define SupportRAS_SUN 0
  #define SupportRAW 0
+ #define SupportSGI 0
  #define SupportTGA 0
  #define SupportTIFF 0
  #define SupportTXT 0
  #define SupportTXTgm 0
+ #define SupportWBMP 0
+ #define SupportWEBP 0
  #define SupportWMF 1
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
  #define SupportXPM 0
 #else
+ #define SupportAAI 2
  #define SupportART 2 	//Read procedure only
+ #define SupportAVS 2
  #define SupportBMP 2	//Read procedure only
  #define SupportCSV 2	//Read procedure only
  #define SupportDIB 2
@@ -52,11 +60,13 @@
  #define SupportTIFF 2
  #define SupportTXT 2	//Read procedure only
  #define SupportTXTgm 2
+ #define SupportWBMP 2
  #define SupportWMF 1	//Use another WMF reader.
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
  #define SupportXPM 2
 #endif
 #define SupportFTG  0
+#define SupportQOI  0
 
 /*----------------------------------------*/
 
@@ -144,6 +154,11 @@
   #define SupportPNG  2
 #endif
 
+#ifndef SupportWEBP
+  #define SupportWEBP  0
+#endif
+
+
 #ifndef SupportFTG
-  #define SupportFTG  10
+  #define SupportFTG  2
 #endif
