@@ -1,15 +1,15 @@
 /******************************************************************************
- * program:     rasimg library 0.28                                           *
+ * program:     rasimg library 0.33                                           *
  * function:    Miscellaneous utilities for manipulation with images.         *
  * modul:       imgut.cc                                                      *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                                   *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include<stdio.h>
 #include<string.h>
 #include<stdlib.h>
 
-#include "../jobs/csext.h"
+#include "csext.h"
 #include "typedfs.h"
 #include "common.h"
 
