@@ -450,7 +450,7 @@ FILE * outfile;		 /* target file */
 JSAMPROW row_pointer[1]; /* pointer to JSAMPLE row[s] */
 int row_stride;		 /* physical row width in image buffer */
 
-  if(Img.Raster==NULL) return ErrMissingRaster;
+  if(Img.Raster==NULL) return ErrEmptyRaster;
 
   /* Step 1: allocate and initialize JPEG compression object */
 
@@ -514,11 +514,11 @@ int row_stride;		 /* physical row width in image buffer */
     i = 0;
     while((Prop=Img.Properties.Find(ExifPreffix,i)) != NULL)
     {
-      int j;
+      unsigned j;
 		// First chunk is scattered into 2 pieces.
       jpeg_write_m_header(&cinfo, JPEG_APP0+1, (int)MIN(Prop->DataSize+6,65533L));
       for(j=0; j<6; j++) jpeg_write_m_byte (&cinfo, ExifPreffix[j]);
-      for(j=0; j<(int)MIN(Prop->DataSize,65533L-6); j++)
+      for(j=0; j<MIN(Prop->DataSize,65533L-6); j++)
           jpeg_write_m_byte (&cinfo, ((unsigned char*)Prop->Data)[j]);
       while(j<Prop->DataSize)
       {
