@@ -22,7 +22,7 @@
 #include "stacks.h"
 #include "struct.h"
 
-#include "images/raster.h"
+#include "raster.h"
 #include "wp2latex.h"
 #include "cp_lib/cptran.h"
 
@@ -1675,7 +1675,7 @@ void TconvertedPass1_WP6::Header_Footer6(void)
 
   Close_All_Attr(attr,strip);
   OldAttr=attr;			/* Backup all attributes */
-  if(Font==FONT_HEBREW || Font==FONT_CYRILLIC || Font==FONT_GEORGIA)
+  if(Font>=FONT_CYRILLIC && Font<=FONT_ARABIC)
       {
       Font = FONT_NORMAL;
       }
