@@ -446,7 +446,7 @@ char OldEnvir;
 long FilePos;
 int i, FieldCount=0;
 char *Prop;
-char *FieldPos=NULL;
+char *FieldPos=NULL;	///< @TODO FieldPos is not allocated!
 char Alignment;
 doublelist PrpL;
 
