@@ -26,7 +26,7 @@
 
 list HTMLChars(Table_html,sizeof(Table_html)/sizeof(char *));
 
-#define HTMLVersion "0.30"
+#define HTMLVersion "0.31"
 
 
 /** Base class for HTML document conversion. */
@@ -459,18 +459,19 @@ void TconvertedPass1_HTML::MetaHTML(void)
   strcpy(ObjType, "Meta");
 
   if((i=TAG_Args IN "content")>=0 || (i=TAG_Args IN "CONTENT")>=0)
-	{
+  {
 	content=TAG_Args.Member(i,1);
 	if(content==NULL) return;
 	charset = strstr(content,"CHARSET");
 	if(charset==NULL) charset = strstr(content,"charset");
 	if(charset==NULL) return;
 	charset+=7;
-	while(*charset==' ') charset++;
+	while(isspace(*charset)) charset++;
 	if(*charset++!='=') return;
+	while(isspace(*charset)) charset++;
 
 	SelectTranslator(charset);
-	}
+  }
 }
 
 
@@ -696,7 +697,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
                           if(by==';')
                             {TAG="\\textrm{;}";by=XML_extchar;break;}
                         }
-                        if(Font==FONT_HEBREW || Font==FONT_CYRILLIC || Font==FONT_GEORGIA)
+                        if(Font>=FONT_CYRILLIC && Font<=FONT_ARABIC)
                         {
                           RequiredFont = FONT_NORMAL;
                         }
