@@ -312,7 +312,7 @@ ImplementReader(SVG,".SVG")
    LoadPictureSVG,
    NULL);
 
-#define SVGVersion "0.14"
+#define SVGVersion "0.15"
 
 
 TconvertedPass1_SVG::TconvertedPass1_SVG(void): DelayedObjects(NULL), objs(NULL) 
@@ -1624,7 +1624,6 @@ void TconvertedPass1_SVG::ImageEmbed(void)
   fprintf(log,"\n#ImageEmbed() ");fflush(log);
 #endif
 int i;
-const char *FileName=NULL;
 string NewFileName;
 float x, y, Width, Height;
 
@@ -1641,7 +1640,7 @@ float x, y, Width, Height;
 
   if((i=TAG_Args IN "src")>=0 || (i=TAG_Args IN "SRC")>=0)
   {
-    FileName = TAG_Args.Member(i,1);
+    const char *FileName = TAG_Args.Member(i,1);
     if(FileName!=NULL)
     {
       for(i=0; i<sizeof(MimeList)/sizeof(TMimeItem); i++)
@@ -1670,7 +1669,7 @@ float x, y, Width, Height;
             fprintf(err,_("\nError: Cannot create image file: \"%s\"."),NewFileName());
           }
         }
-      FileName = NewFileName();
+        //FileName = NewFileName();
       }
     }
   }
@@ -1692,7 +1691,7 @@ float x, y, Width, Height;
           if(!strncmp(Mime,MimeList[i].MimeType,MimeList[i].TypeLen))
           {
             NewFileName = MergePaths(OutputDir,RelativeFigDir) + GetSomeImgName(MimeList[i].ImageExt);
-            FileName += MimeList[i].TypeLen + 1;
+            //FileName += MimeList[i].TypeLen + 1;
             break;
           }
         }
@@ -1716,7 +1715,7 @@ float x, y, Width, Height;
         {
           base64_decode(Contents, F);
           fclose(F);
-          FileName = NewFileName();
+          //FileName = NewFileName();
         }
         else
         {
@@ -1755,15 +1754,20 @@ float x, y, Width, Height;
   if(!NewFileName.isEmpty())
   {
     Image Img2(LoadPicture(NewFileName()));
-    if(!Img2.isEmpty())
+    if(!Img2.isEmpty() && Img2.Raster!=NULL)
     {
-      if(Img2.Raster!=NULL)
+      VectorRaster *VecR = new VectorRaster(y, y+Height, x+Width, x);
+      VecR->AttachRaster(Img2.Raster);
+      VecR->AttachPalette(Img2.Palette);
+      VecR->CalcBoundingBox(bbx);
+      VectList.AddObject(VecR);
+    }
+    else
+    {
+      if(err != NULL)
       {
-         VectorRaster *VecR = new VectorRaster(y, y+Height, x+Width, x);
-         VecR->AttachRaster(Img2.Raster);
-         VecR->AttachPalette(Img2.Palette);
-         VecR->CalcBoundingBox(bbx);
-         VectList.AddObject(VecR);
+        perc.Hide();
+        fprintf(err,_("\nError: Cannot load image file: \"%s\"."),NewFileName());
       }
     }
   }
