@@ -164,13 +164,30 @@ if(c=='<')	//Handle HTML tag
     if(c=='>') {TAG += MakeUpper?toupper(c):c; return;}
     if(isspace(c))
     {
-      if(TAG[1]=='!')
+      if(TAG[1]=='!' && TAG[2]=='-' && TAG[3]=='-')
       {
+        unsigned char Status = 0;        
+
+        Value.erase();
         do {
-          if((c=fgetc(wpd)) == EOF) return;
-          if(c==0) return;			 //illegal 0 char
-          TAG += c;		//read all comment
-        } while (c!='>');
+          if((c=fgetc(wpd)) == EOF) return;    
+          switch(c)
+          {     
+            case 0: return;			 //illegal 0 char
+            case '-':if(Status<2) Status++;
+                    Value += c;
+                    break;
+            case '>':if(Status==2)
+                    {
+                      Status++;
+                      break;
+                    }
+		    // fall down no break.
+            default:Status = 0;
+                    Value += c;		//read whole comment
+                    break;
+          }          
+        } while(Status<3);
         by = XML_comment;
         return;
       }
