@@ -7,14 +7,15 @@
 #ifndef __PASS1_XML_H__
 #define __PASS1_XML_H__
 
+
 class TconvertedPass1_XML: virtual public TconvertedPass1
      {
 public:
-     DWORD (*CharReader)(FILE *F);
+     uint32_t (*CharReader)(FILE *F);
      CpTranslator *ConvertHTML;
      string TAG;
      doublelist TAG_Args;
-     BYTE TablePos;
+     uint8_t TablePos;
 
      void SelectTranslator(const char *CharSet);
 
@@ -44,4 +45,23 @@ typedef enum
 } XML_STATUS;
 
 
+typedef struct
+{
+  const char* MimeType;
+  int TypeLen;
+  const char *ImageExt;
+} TMimeItem;
+
+// See: https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Complete_list_of_MIME_types
+extern const TMimeItem MimeList[8];
+
+
+void base64_decode(const char *encoded_string, FILE *FOut);
+
+inline bool is_base64(uint8_t c)
+{
+ return (isalnum(c) || (c == '+') || (c == '/'));
+}
+
+
 #endif	//#define __PASS1_XML_H__
