@@ -1622,6 +1622,26 @@ const TOutCodePage OutCodepages[12] =
 };
 
 
+void ShowHelpImages(void)
+{
+TImageFileHandler *LoadPicture_XXX;
+
+  fprintf(err, _("Supported image formats:\n"));
+  for(LoadPicture_XXX=TImageFileHandler::first();LoadPicture_XXX!=NULL;LoadPicture_XXX=LoadPicture_XXX->next())
+  {
+    fprintf(err, "%s%s%s %s%s; ",LoadPicture_XXX->extension(),
+			LoadPicture_XXX->description()==NULL?"":"#",
+			LoadPicture_XXX->description()==NULL?"":LoadPicture_XXX->description(),
+			LoadPicture_XXX->LoadPicture==NULL?"":"R",
+			LoadPicture_XXX->SavePicture==NULL?"":"W");
+    if(LoadPicture_XXX->Flags & FILE_FORMAT_CAP_EXIF) fputs("+EXIF",err);
+    //if(LoadPicture_XXX->Flags & FILE_FORMAT_256_COLORS) printf("-MAX256Colors");
+    if(LoadPicture_XXX->Flags & FILE_FORMAT_DUPLICATE) fputs(_("(duplicated)"),err);
+    printf("\n");
+  }
+}
+
+
 /** This procedure handles parameters and the filenames*/
 int CommandLine(int argc, char *argv[])
 {
@@ -2082,10 +2102,10 @@ int p;
 		FFormatTranslator *Fx;
 		Fx = FFormatTranslator::first();
 		while(Fx!=NULL)
-		  {
+		{
 		  fprintf(err, (Fx->next()==NULL)?"%s":"%s,", Fx->shortkey());
 		  Fx = Fx->next();
-		  }
+		}
 		fprintf(err,")\n");
 		TImageFileHandler *LoadPicture_XXX;
 	        fprintf(err,_("  Supported Image formats:"));
@@ -2097,7 +2117,22 @@ int p;
 		         LoadPicture_XXX->SavePicture==NULL?"":"W",
                          LoadPicture_XXX->next()==NULL?"":"; ");
 		    }
-	        fprintf(err,"\n");
+                fprintf(err,_("\n  Supported code pages:"));
+                CpTranslator *Ptrn = CpTranslator::getFirst();
+                while(Ptrn!=NULL)
+                {
+                  if(Ptrn->Name)
+                  {
+                    const char *ToS = strstr(Ptrn->Name,"TOinternal");
+                    if(ToS)
+                    {
+                      const string str(Ptrn->Name,ToS-Ptrn->Name);
+                      fprintf(err," %s",str());
+                    }
+                  }
+                  Ptrn = Ptrn->getNext();
+                }
+                fprintf(err,"\n");
 #ifdef CORELEFT
 		fprintf(err,"  free memory %ld\n",CORELEFT());
 #endif
@@ -2116,6 +2151,10 @@ int p;
            CheckGettext(argv==NULL?NULL:*argv, "wp2latex");
 #endif
 	   Heading();
+           if(CheckArg(p,argc,argv[p]))
+           {
+             if(!strcmp(argv[p],"images")) {ShowHelpImages();RunError(-2);return(0);}
+           }
 	   ShowHelp();
 	   RunError(-2); return(0);
 	   }
